@@ -1,6 +1,7 @@
 import re
 import os
 import keyring
+import subprocess
 from selenium import webdriver
 from selenium.webdriver.chrome.options import Options
 from contextlib import contextmanager
@@ -21,11 +22,25 @@ class BaseScrap:
     def pw(self):
         return self._bw_password
 
-    def _bw_password(self):
+
+    def _bw_cmd_get_pw(self):
+        return ['bw', 'get', 'password']
+
+    def _bw_cmd_get_pw_with_session(self):
+        returned = self._bw_cmd_get_pw()
+
         if os.environ.get('BW_SESSION') is None:
             raise MissingBitWardenToken('You did not login to bitwarden - Expecting BW_SESSION env var..')
-        return keyring.get_password(self.bw_service,
-                                    self.username)
+
+        returned.append('--session')
+        returned.append(os.environ.get('BW_SESSION'))
+        returned.append(self.bw_service)
+        return returned
+
+    def _bw_password(self):
+        return subprocess.check_output(self._bw_cmd_get_pw_with_session())
+        # return keyring.get_password(self.bw_service,
+        #                             self.username)
 
     def set_attrs_by_cfg_params(self, cfg):
         ''' config may contain keys like _param_<param name>
